@@ -1,6 +1,6 @@
 /* channel.c
  *
- * $Id: channel.c,v 1.105 2001/09/27 12:08:11 nisse Exp $
+ * $Id: channel.c,v 1.106 2001/10/29 18:36:57 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -1906,8 +1906,9 @@ channel_read_close_callback(struct lsh_callback *c)
   trace("channel_read_close_callback: File closed.\n");
 
   assert(closure->channel->sources);
-  
-  if (!--closure->channel->sources)
+
+  closure->channel->sources--;
+  if (!closure->channel->sources)
     {
       /* Send eof, unless already done. */
       channel_eof(closure->channel);
