@@ -2,7 +2,7 @@
  *
  * Client side of X11 forwaarding.
  *
- * $Id: client_x11.c,v 1.15 2001/09/27 06:34:59 nisse Exp $ */
+ * $Id: client_x11.c,v 1.17 2001/12/12 18:42:59 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -600,7 +600,7 @@ make_client_x11_display(const char *display, struct lsh_string *fake)
   
   if (!parse_display(self, display))
     {
-      werror("Can't parse X11 display: `%s'\n", display);
+      werror("Can't parse X11 display: `%z'\n", display);
       KILL(self);
       return NULL;
     }
@@ -732,6 +732,8 @@ make_forward_x11(const char *display_string,
   struct lsh_string *fake = lsh_string_alloc(X11_COOKIE_LENGTH);
   struct client_x11_display *display;
 
+  assert(random->quality == RANDOM_GOOD);
+  
   RANDOM(random, fake->length, fake->data);
 
   debug("Generated X11 fake cookie %xS\n", fake);
