@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: dh_exchange.c,v 1.12 2001/02/25 22:38:18 nisse Exp $ */
+ * $Id: dh_exchange.c,v 1.13 2001/12/12 18:42:59 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -28,10 +28,13 @@
 #include "connection.h"
 #include "crypto.h"
 #include "format.h"
+#include "randomness.h"
 #include "ssh.h"
 #include "werror.h"
 #include "xalloc.h"
 
+#include <assert.h>
+
 void
 init_dh_instance(struct dh_method *m,
 		 struct dh_instance *self,
@@ -71,6 +74,9 @@ make_dh(struct abstract_group *G, struct hash_algorithm *H,
 	struct randomness *r)
 {
   NEW(dh_method, res);
+
+  assert(r->quality == RANDOM_GOOD);
+  
   res->G = G;
   res->H = H;
   res->random = r;
