@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: io.h,v 1.85 2001/10/02 16:15:23 nisse Exp $ */
+ * $Id: io.h,v 1.86 2001/10/30 19:47:55 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -331,7 +331,11 @@ void close_fd(struct lsh_fd *fd);
 void close_fd_nicely(struct lsh_fd *fd);
 
 /* Stop reading, but if the fd has a write callback, keep it open. */
-void close_fd_read(struct lsh_fd *fd);
+void
+close_fd_read(struct lsh_fd *fd);
+
+void
+close_fd_write(struct lsh_fd *fd);
 
 struct lsh_fd *
 io_write_file(const char *fname, int flags,
