@@ -2,7 +2,7 @@
  *
  * Reads a (private) key on stdin, and saves it a private and a public file.
  *
- * $Id: lsh-writekey.c,v 1.21 2001/10/03 15:10:31 nisse Exp $ */
+ * $Id: lsh-writekey.c,v 1.22 2001/12/12 18:37:54 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -101,8 +101,8 @@ make_lsh_writekey_options(void)
   self->signature_algorithms = all_signature_algorithms(NULL);
 
   /* We use this only for salt and iv generation. */
-  self->r = make_bad_random();
-
+  self->r = make_user_random(getenv("HOME"));
+  
   /* A better default would be crypto_cbc(make_des3()) */
   self->crypto = NULL;
   
@@ -289,7 +289,7 @@ open_private_file(const struct lsh_string *file)
                 0600);
 
   if (fd < 0)
-    werror("Failed to open `%z'for writing: %z\n"
+    werror("Failed to open `%S'for writing: %z\n"
            "lsh-writekey doesn't overwrite existing key files.\n"
            "If you *really* want to do that, you should delete\n"
            "the existing files first\n",
