@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: read_packet.c,v 1.48 2000/08/04 00:04:50 nisse Exp $ */
+ * $Id: read_packet.c,v 1.50 2001/10/24 16:58:07 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -51,10 +51,6 @@
      (vars
        (state . int)
   
-       ; This is usually initialized from the command
-       ; that created the fd.
-       ;; (e object exception_handler)
-
        ; Attached to read packets
        (sequence_number . UINT32)
   
@@ -114,8 +110,16 @@ do_read_packet(struct read_handler **h,
   if (!available)
     {
       debug("read_packet: EOF in state %i\n", closure->state);
-      EXCEPTION_RAISE(closure->connection->e,
-		      make_protocol_exception(0, "Unexpected EOF"));
+
+      if (closure->state != WAIT_START)
+        EXCEPTION_RAISE(closure->connection->e,
+                        make_protocol_exception(0, "Unexpected EOF"));
+      else
+        /* FIXME: This may still be "unexpected".
+         *
+         * We should check that there's no open channels. */
+        EXCEPTION_RAISE(closure->connection->e, &finish_read_exception);
+      
       *h = NULL;
       return 0;
     }
