@@ -4,7 +4,7 @@
  * processes and ports. Used to kill or release the resource in
  * question when the connection dies.
  *
- * $Id: resource.c,v 1.18 2001/09/01 10:43:38 nisse Exp $ */
+ * $Id: resource.c,v 1.23 2001/10/03 13:45:14 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -55,22 +55,12 @@ void do_free_resources(struct resource_node **q);
 
 /* Sanity check */
 
-/* NOTE: This happens normally during gc_final. Under all other
- * circumstances, it's a serious error. */
 void
 dont_free_live_resource(int alive)
 {
   if (alive)
-    {
-#if DEBUG_ALLOC
-      if (gc_final_p)
-	verbose("dont_free_live_resource: "
-		"final collection of a live resource!\n");
-      else
-#endif
-	fatal("dont_free_live_resource: "
-	      "garbage collecting a live resource!\n");
-    }
+    fatal("dont_free_live_resource: "
+          "garbage collecting a live resource!\n");
 }
 
 /* For resources that are only marked as dead, and taken care of
@@ -97,6 +87,7 @@ struct resource_node
   struct resource *resource;
 };
 
+/* Works as a weak list of resources. */
 /* GABA:
    (class
      (name concrete_resource_list)
@@ -170,6 +161,8 @@ do_kill_all(struct resource *s)
   CAST(concrete_resource_list, self, s);
   struct resource_node *n;
 
+  trace("do_kill_all: resource_list %xi\n", self);
+  
   for (n = self->q; n; )
     {
       CAST_SUBTYPE(resource, r, n->resource);
@@ -185,12 +178,12 @@ do_kill_all(struct resource *s)
 }
   
 struct resource_list *
-empty_resource_list(void)
+make_resource_list(void)
 {
   NEW(concrete_resource_list, self);
   init_resource(&self->super.super, do_kill_all);
 
-  trace("empty_resource_list: created %xi\n", self);
+  trace("make_resource_list: created %xi\n", self);
   self->super.remember = do_remember_resource;
   
   self->q = NULL;
