@@ -4,7 +4,7 @@
  * processes and ports. Used to kill or release the resource in
  * question when the connection dies.
  *
- * $Id: resource.h,v 1.11 2001/09/01 10:43:38 nisse Exp $ */
+ * $Id: resource.h,v 1.13 2001/09/27 06:43:32 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -65,6 +65,6 @@ init_resource(struct resource *self,
 #define KILL_RESOURCE_LIST(l) KILL_RESOURCE(&(l)->super)
 
 /* Allocates an empty list. */
-struct resource_list *empty_resource_list(void);
+struct resource_list *make_resource_list(void);
 
 #endif /* LSH_RESOURCE_H_INCLUDED */
