@@ -1,6 +1,6 @@
 /* rsa.c
  *
- * $Id: rsa.c,v 1.12 2000/11/26 23:25:59 nisse Exp $
+ * $Id: rsa.c,v 1.17 2001/12/12 19:26:17 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -127,7 +127,7 @@ rsa_check_size(struct rsa_verifier *key)
   key->size = (mpz_sizeinbase(key->n, 2) + 7) / 8;
 
   /* For PKCS#1 to make sense, the size of the modulo, in octets, must
-   * be at least 1 + the length of the DER-encoded Digest Info.
+   * be at least 11 + the length of the DER-encoded Digest Info.
    *
    * And a DigestInfo is 34 octets for md5, and 35 octets for sha1.
    * 46 octets is 368 bits. */
@@ -209,6 +209,7 @@ do_rsa_verify(struct verifier *v,
   
   switch(algorithm)
     {
+#if 0
     case ATOM_RSA_PKCS1_SHA1:
     case ATOM_RSA_PKCS1_SHA1_LOCAL:
 
@@ -217,8 +218,33 @@ do_rsa_verify(struct verifier *v,
   
       bignum_parse_u(s, signature_length, signature_data);
       break;
-      
+
     case ATOM_SPKI:
+#endif
+    case ATOM_SSH_RSA:
+      {
+	struct simple_buffer buffer;
+	UINT32 length;
+	const UINT8 *digits;
+	int atom;
+	
+	simple_buffer_init(&buffer, signature_length, signature_data);
+
+	if (!(parse_atom(&buffer, &atom)
+	      && (atom == ATOM_SSH_RSA)
+	      && parse_string(&buffer, &length, &digits)
+	      && (length <= self->size)
+	      && parse_eod(&buffer) ))
+	  goto fail;
+
+	bignum_parse_u(s, length, digits);
+
+	break;
+      }
+      
+      /* It doesn't matter here which flavour of SPKI is used. */
+    case ATOM_SPKI_SIGN_RSA:
+    case ATOM_SPKI_SIGN_DSS:
       {
 	struct simple_buffer buffer;
 	struct sexp *e;
@@ -232,6 +258,7 @@ do_rsa_verify(struct verifier *v,
 
 	break;
       }
+      
     default:
       fatal("do_rsa_verify: Internal error!\n");
     }
@@ -269,8 +296,8 @@ do_rsa_public_key(struct verifier *s)
 {
   CAST(rsa_verifier, self, s);
 
-  return ssh_format("%a%n%n", ATOM_SSH_RSA_PKCS1_LOCAL,
-		     self->n, self->e);
+  return ssh_format("%a%n%n", ATOM_SSH_RSA,
+		     self->e, self->n);
 }
 
 static struct sexp *
@@ -284,6 +311,12 @@ do_rsa_public_spki_key(struct verifier *s)
 		-1);
 }
 
+/* NOTE: To initialize an rsa verifier, one must
+ *
+ * 1. Call this function.
+ * 2. Initialize the modulo n and exponent e.
+ * 3. Call rsa_check_size.
+ */
 static void
 init_rsa_verifier(struct rsa_verifier *self, struct rsa_algorithm *params)
 {
@@ -294,6 +327,8 @@ init_rsa_verifier(struct rsa_verifier *self, struct rsa_algorithm *params)
   mpz_init(self->n);
   mpz_init(self->e);
 
+  self->size = 0;
+
   self->super.verify = do_rsa_verify;
   self->super.verify_spki = do_rsa_verify_spki;
   self->super.public_key = do_rsa_public_key;
@@ -320,6 +355,29 @@ make_rsa_verifier_internal(struct rsa_algorithm *params,
     }
 }
   
+/* Alternative constructor using a key of type ssh-rsa, when the atom
+ * "ssh-rsa" is already read from the buffer. */
+struct verifier *
+parse_ssh_rsa_public(struct simple_buffer *buffer)
+{
+  NEW(rsa_verifier, res);
+  init_rsa_verifier(res, &rsa_sha1_algorithm);
+
+  if (parse_bignum(buffer, res->e, RSA_MAX_SIZE)
+      && (mpz_sgn(res->e) == 1)
+      && parse_bignum(buffer, res->n, RSA_MAX_SIZE)
+      && (mpz_sgn(res->n) == 1)
+      && (mpz_cmp(res->e, res->n) < 0)
+      && parse_eod(buffer)
+      && rsa_check_size(res))
+    return &res->super;
+
+  else
+    {
+      KILL(res);
+      return NULL;
+    }
+}
 
 /* Signature creation */
 
@@ -404,7 +462,7 @@ rsa_compute_root(struct rsa_signer *self, mpz_t x, mpz_t m)
      *
      * We also get 0 <= xq + q xp' < p q, because
      *
-     *   0 <= xq < q and 0 <= * xp' < p.
+     *   0 <= xq < q and 0 <= xp' < p.
      */
     mpz_mul(x, self->q, xp);
     mpz_add(x, x, xq);
@@ -437,6 +495,16 @@ do_rsa_sign(struct signer *s,
 
   switch (algorithm)
     {
+    case ATOM_SSH_RSA:
+      /* Uses the encoding:
+       *
+       * string ssh-rsa
+       * string signature-blob
+       */
+  
+      res = ssh_format("%a%un", ATOM_SSH_RSA, m);
+      break;
+#if 0
     case ATOM_RSA_PKCS1_SHA1:
     case ATOM_RSA_PKCS1_SHA1_LOCAL:
       /* Uses the encoding:
@@ -447,8 +515,11 @@ do_rsa_sign(struct signer *s,
   
       res = ssh_format("%a%un", ATOM_RSA_PKCS1_SHA1, m);
       break;
+#endif
+      /* It doesn't matter here which flavour of SPKI is used. */
+    case ATOM_SPKI_SIGN_RSA:
+    case ATOM_SPKI_SIGN_DSS:
 
-    case ATOM_SPKI:
       res = sexp_format(encode_rsa_sig_val(m), SEXP_CANONICAL, 0);
       break;
     default:
@@ -507,6 +578,13 @@ make_rsa_signer(struct signature_algorithm *s,
   CAST(rsa_algorithm, params, s);
   NEW(rsa_signer, res);
 
+  mpz_init(res->d);
+  mpz_init(res->p);
+  mpz_init(res->q);
+  mpz_init(res->a);
+  mpz_init(res->b);
+  mpz_init(res->c);
+  
   if ( (SEXP_LEFT(i) == 8)
        && ( (res->verifier = make_rsa_verifier_internal(params, i)) )
        && sexp_get_un(i, ATOM_D, res->d, RSA_MAX_SIZE)
@@ -602,3 +680,17 @@ static const UINT8 sha1_prefix[] =
 struct rsa_algorithm rsa_sha1_algorithm =
 STATIC_RSA_ALGORITHM(&sha1_algorithm, ATOM_RSA_PKCS1_SHA1, 15, sha1_prefix);
 
+struct verifier *
+make_ssh_rsa_verifier(UINT32 public_length,
+		      const UINT8 *public)
+{
+  struct simple_buffer buffer;
+  int atom;
+  
+  simple_buffer_init(&buffer, public_length, public);
+
+  return ( (parse_atom(&buffer, &atom)
+	    && (atom == ATOM_SSH_RSA))
+	   ? parse_ssh_rsa_public(&buffer)
+	   : NULL);
+}
