@@ -2,7 +2,7 @@
  *
  * Generate rsa key pairs..
  *
- * $Id: rsa_keygen.c,v 1.4 2001/06/09 16:00:37 nisse Exp $
+ * $Id: rsa_keygen.c,v 1.7 2001/12/16 15:31:50 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -26,9 +26,12 @@
 
 #include "rsa.h"
 
+#include "randomness.h"
 #include "sexp.h"
 #include "werror.h"
 
+#include <assert.h>
+
 #define SA(x) sexp_a(ATOM_##x)
 
 /* Takes the public exponent e as argument. */
@@ -36,7 +39,7 @@ struct sexp *
 rsa_generate_key(mpz_t e, struct randomness *r, UINT32 bits)
 {
   struct sexp *key = NULL;
-  
+
   mpz_t n;
   mpz_t d;
   mpz_t p; mpz_t q;
@@ -44,6 +47,8 @@ rsa_generate_key(mpz_t e, struct randomness *r, UINT32 bits)
   mpz_t phi;
   mpz_t tmp;
   
+  assert(r->quality == RANDOM_GOOD);
+  
   mpz_init(n); mpz_init(d); mpz_init(p), mpz_init(q);
   mpz_init(a); mpz_init(b); mpz_init(c);
 
@@ -103,7 +108,7 @@ rsa_generate_key(mpz_t e, struct randomness *r, UINT32 bits)
   if (mpz_sgn(c) < 0)
     mpz_fdiv_r(c, c, p);
 
-  debug("a = %xn\n", c);
+  debug("c = %xn\n", c);
 
   /* FIXME: Add sanity checking */
   
