@@ -1,6 +1,6 @@
 /* server_session.c
  *
- * $Id: server_session.c,v 1.73 2001/09/28 21:27:00 nisse Exp $
+ * $Id: server_session.c,v 1.76 2001/12/05 12:35:47 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -133,7 +133,15 @@ do_eof(struct ssh_channel *channel)
 
   trace("server_session.c: do_eof\n");
 
-  close_fd_nicely(session->in);
+  if (session->pty)
+    /* Is there any better way to signal EOF on a pty? This is what
+     * emacs does. */
+    /* FIXME: This should be handled specially by close_fd_write, so
+     * that we can ignore EPIPE errors. */
+    A_WRITE(&session->in->write_buffer->super,
+            ssh_format("%lc", /* C-d */ 4));
+
+  close_fd_write(session->in);
 }
 
 struct ssh_channel *
@@ -765,7 +773,8 @@ DEFINE_CHANNEL_REQUEST(exec_request_handler)
 
 	    assert(getuid() == channel->connection->user->uid);
 	    assert(argv[2]);
-	    
+
+	    /* FIXME: Set SSH_TTY, SSH_CLIENT and SSH_ORIGINAL_COMMAND */
 	    if (session->term)
 	      {
 		env[env_length].name ="TERM";
