@@ -1,6 +1,6 @@
 /* sftp-server.c
  *
- * $Id: sftp-server.c,v 1.11 2001/08/27 13:45:03 nisse Exp $
+ * $Id: sftp-server.c,v 1.14 2001/11/23 12:53:27 nisse Exp $
  *
  * The server side of the sftp subsystem. */
 
@@ -205,11 +205,10 @@ sftp_attrib_from_stat(struct stat *st, struct sftp_attrib* a)
   a->atime=st->st_atime;
   a->mtime=st->st_mtime;
   a->size=st->st_size;
-  a->flags= ( SSH_FILEXFER_ATTR_SIZE ||
-	      SSH_FILEXFER_ATTR_UIDGID ||
-	      SSH_FILEXFER_ATTR_PERMISSIONS || 
-	      SSH_FILEXFER_ATTR_ACMODTIME
-	      );
+  a->flags= ( SSH_FILEXFER_ATTR_SIZE
+              | SSH_FILEXFER_ATTR_UIDGID
+              | SSH_FILEXFER_ATTR_PERMISSIONS
+              | SSH_FILEXFER_ATTR_ACMODTIME);
 }
 
 static void
@@ -526,6 +525,10 @@ sftp_process_readdir(struct sftp_ctx *ctx)
   if (!sftp_get_handle_dir(ctx, &dir))
     return sftp_bad_message(ctx);
 
+  /* readdir doesn't modify errno on EOF, so we need to clear it
+   * first. */
+  errno = 0;
+  
   entry=readdir(dir->dir);
 
   if (!entry)
@@ -985,9 +988,9 @@ sftp_process_read(struct sftp_ctx *ctx)
   /* Check so we are to read at all */
   if (length)
     {
-      size_t done = 0;
-      int res;
+      UINT32 done = 0;
       UINT32 index;
+      int res;
 
       DEBUG (("sftp_process_read: fd = %d\n", f->fd));
       
